weaviate.classification package
===============================

.. automodule:: weaviate.classification
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

weaviate.classification.classification module
---------------------------------------------

.. automodule:: weaviate.classification.classification
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.classification.config\_builder module
----------------------------------------------

.. automodule:: weaviate.classification.config_builder
   :members:
   :undoc-members:
   :show-inheritance:
